@@ -7,6 +7,13 @@ from tornado.web import RequestHandler
 
 
 class BaseHandler(RequestHandler):
+    def on_finish(self):
+        if self.application.config.COMMIT_ON_REQUEST_END:
+            if self.get_status() > 399:
+                self.db.rollback()
+            else:
+                self.db.commit()
+
     def options(self):
         self.set_header('Access-Control-Allow-Origin', self.application.config.ORIGIN)
         self.set_header('Access-Control-Allow-Methods', 'GET,PUT,POST,DELETE,OPTIONS')
@@ -21,3 +28,7 @@ class BaseHandler(RequestHandler):
     def write_json(self, obj):
         self.set_header("Content-Type", "application/json")
         self.write(dumps(obj))
+
+    @property
+    def db(self):
+        return self.application.sqlalchemy_db
