@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+
 from cow.server import Server
-from cow.plugins.motorengine_plugin import MotorEnginePlugin
+#from cow.plugins.motorengine_plugin import MotorEnginePlugin
+from cow.plugins.sqlalchemy_plugin import SQLAlchemyPlugin
 from tornado.httpclient import AsyncHTTPClient
 
 from holmes.handlers.worker import WorkerHandler, WorkersHandler
@@ -14,12 +16,18 @@ from holmes.handlers.fact import CreateFactHandler
 from holmes.handlers.violation import (
     CreateViolationHandler, MostCommonViolationsHandler
 )
-from holmes.handlers.review import ReviewHandler, CompleteReviewHandler
+from holmes.handlers.review import (
+    ReviewHandler, CompleteReviewHandler, LastReviewsHandler
+)
 from holmes.handlers.next_job import NextJobHandler
 from holmes.handlers.domains import (
     DomainsHandler, DomainDetailsHandler, DomainViolationsPerDayHandler,
     DomainReviewsHandler
 )
+from holmes.handlers.search import (
+    SearchHandler
+)
+
 
 
 def main():
@@ -31,6 +39,7 @@ class HolmesApiServer(Server):
     def get_handlers(self):
         handlers = [
             (r'/most-common-violations/?', MostCommonViolationsHandler),
+            (r'/last-reviews/?', LastReviewsHandler),
             (r'/workers/?', WorkersHandler),
             (r'/worker/([a-z0-9-]*)/(alive|dead)/?', WorkerHandler),
             (r'/worker/([a-z0-9-]*)/review/([a-z0-9-]*)/(start|complete)', WorkerStateHandler),
@@ -41,6 +50,7 @@ class HolmesApiServer(Server):
             (r'/page/([a-z0-9-]*)/reviews/?', PageReviewsHandler),
             (r'/page/([a-z0-9-]*)/violations-per-day/?', PageViolationsPerDayHandler),
             (r'/page/([a-z0-9-]*)/?', PageHandler),
+            (r'/search/?', SearchHandler),
             (r'/page/?', PageHandler),
             (r'/pages/?', PagesHandler),
             (r'/domains/?', DomainsHandler),
@@ -54,9 +64,11 @@ class HolmesApiServer(Server):
 
     def get_plugins(self):
         return [
-            MotorEnginePlugin,
+            SQLAlchemyPlugin
         ]
 
+    def after_start(self, io_loop):
+        self.application.http_client = AsyncHTTPClient(io_loop=io_loop)
 
 if __name__ == '__main__':
     main()
