@@ -19,8 +19,7 @@ class TestReviewHandler(ApiTestCase):
 
     @gen_test
     def test_invalid_review_returns_404(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
+        page = PageFactory.create()
 
         url = self.get_url('/page/%s/review/invalid' % page.uuid)
 
@@ -39,17 +38,16 @@ class TestReviewHandler(ApiTestCase):
 
     @gen_test
     def test_can_get_review(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        review = ReviewFactory.create()
 
         review.add_fact('fact', 'value', 'title', 'kb')
         review.add_violation('violation', 'title', 'description', 100)
-        yield review.save()
+
+        self.db.flush()
 
         url = self.get_url(
             '/page/%s/review/%s' % (
-                page.uuid,
+                review.page.uuid,
                 review.uuid
             )
         )
@@ -61,8 +59,8 @@ class TestReviewHandler(ApiTestCase):
         dt = calendar.timegm(datetime.now().utctimetuple())
 
         expected = {
-            'domain': domain.name,
-            'page': page.to_dict(),
+            'domain': review.domain.name,
+            'page': review.page.to_dict(),
             'uuid': str(review.uuid),
             'isComplete': False,
             'facts': [
@@ -74,7 +72,8 @@ class TestReviewHandler(ApiTestCase):
             'createdAt': dt,
             'completedAt': None,
             'violationPoints': 100,
-            'violationCount': 1
+            'violationCount': 1,
+            'completedDateISO': None
         }
 
         expect(loads(response.body)).to_be_like(expected)
@@ -84,8 +83,7 @@ class TestCompleteReviewHandler(ApiTestCase):
 
     @gen_test
     def test_invalid_review_returns_404(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
+        page = PageFactory.create()
 
         url = self.get_url('/page/%s/review/invalid/complete' % page.uuid)
 
@@ -106,13 +104,11 @@ class TestCompleteReviewHandler(ApiTestCase):
     @gen_test
     def test_can_complete_review(self):
         dt = datetime.now()
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        review = ReviewFactory.create()
 
         url = self.get_url(
             '/page/%s/review/%s/complete' % (
-                page.uuid,
+                review.page.uuid,
                 review.uuid
             )
         )
@@ -121,30 +117,28 @@ class TestCompleteReviewHandler(ApiTestCase):
 
         expect(response.code).to_equal(200)
 
-        review = yield Review.objects.get(review._id)
-        yield review.load_references(['page'])
-        yield review.page.load_references(['last_review'])
+        review = self.db.query(Review).get(review.id)
 
         expect(review.is_complete).to_be_true()
         expect(review.is_active).to_be_true()
         expect(review.completed_date).to_be_greater_or_equal_to(dt)
-        expect(review.page.last_review._id).to_equal(review._id)
+        expect(review.page.last_review.id).to_equal(review.id)
 
     @gen_test
     def test_completing_reviews_inactivates_old_reviews(self):
         dt = datetime.now()
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        page2 = yield PageFactory.create(domain=domain)
+        domain = DomainFactory.create()
+        page = PageFactory.create(domain=domain)
+        page2 = PageFactory.create(domain=domain)
 
-        review = yield ReviewFactory.create(
+        review = ReviewFactory.create(
             page=page,
             is_complete=True,
             is_active=True,
             created_date=dt-timedelta(days=1))
 
-        review2 = yield ReviewFactory.create(page=page, is_complete=False, is_active=False)
-        review3 = yield ReviewFactory.create(page=page2, is_complete=True, is_active=True)
+        review2 = ReviewFactory.create(page=page, is_complete=False, is_active=False)
+        review3 = ReviewFactory.create(page=page2, is_complete=True, is_active=True)
 
         url = self.get_url(
             '/page/%s/review/%s/complete' % (
@@ -157,35 +151,31 @@ class TestCompleteReviewHandler(ApiTestCase):
 
         expect(response.code).to_equal(200)
 
-        loaded_review = yield Review.objects.get(review2._id)
-        yield loaded_review.load_references(['page'])
-        yield loaded_review.page.load_references(['last_review'])
+        loaded_review = self.db.query(Review).get(review2.id)
 
         expect(loaded_review).not_to_be_null()
         expect(loaded_review.is_complete).to_be_true()
         expect(loaded_review.is_active).to_be_true()
         expect(loaded_review.completed_date).to_be_greater_or_equal_to(dt)
-        expect(loaded_review.page.last_review._id).to_equal(review2._id)
+        expect(loaded_review.page.last_review.id).to_equal(review2.id)
 
-        loaded_review = yield Review.objects.get(review._id)
+        loaded_review = self.db.query(Review).get(review.id)
         expect(loaded_review).not_to_be_null()
         expect(loaded_review.is_complete).to_be_true()
         expect(loaded_review.is_active).to_be_false()
 
-        loaded_review = yield Review.objects.get(review3._id)
+        loaded_review = self.db.query(Review).get(review3.id)
         expect(loaded_review).not_to_be_null()
         expect(loaded_review.is_complete).to_be_true()
         expect(loaded_review.is_active).to_be_true()
 
     @gen_test
     def test_cant_complete_review_twice(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page, is_complete=True)
+        review = ReviewFactory.create(is_complete=True)
 
         url = self.get_url(
             '/page/%s/review/%s/complete' % (
-                page.uuid,
+                review.page.uuid,
                 review.uuid
             )
         )
@@ -208,14 +198,9 @@ class TestCompleteReviewHandler(ApiTestCase):
     def test_same_day_review_removes_older(self):
         dt = datetime.now()
 
-        yield Page.objects.delete()
-        yield Domain.objects.delete()
-        yield Review.objects.delete()
-
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review_yesterday = yield ReviewFactory.create(page=page, created_date=(dt-timedelta(days=1)))
-        review_old = yield ReviewFactory.create(page=page, created_date=dt)
+        page = PageFactory.create()
+        review_yesterday = ReviewFactory.create(page=page, created_date=(dt-timedelta(days=1)))
+        review_old = ReviewFactory.create(page=page, created_date=dt)
 
         url = self.get_url(
             '/page/%s/review/%s/complete' % (
@@ -226,7 +211,7 @@ class TestCompleteReviewHandler(ApiTestCase):
         response = yield self.http_client.fetch(url, method='POST', body='')
         expect(response.code).to_equal(200)
 
-        review_new = yield ReviewFactory.create(page=page, created_date=dt)
+        review_new = ReviewFactory.create(page=page, created_date=dt)
 
         url = self.get_url(
             '/page/%s/review/%s/complete' % (
@@ -237,7 +222,7 @@ class TestCompleteReviewHandler(ApiTestCase):
         response = yield self.http_client.fetch(url, method='POST', body='')
         expect(response.code).to_equal(200)
 
-        reviews = yield Review.objects.filter(page=page).find_all()
+        reviews = self.db.query(Review).filter(Review.page_id == page.id).all()
 
         reviews_uuids = []
         for review in reviews:
@@ -247,3 +232,52 @@ class TestCompleteReviewHandler(ApiTestCase):
         expect(reviews_uuids).to_include(str(review_yesterday.uuid))
         expect(reviews_uuids).to_include(str(review_new.uuid))
         expect(reviews_uuids).not_to_include(str(review_old.uuid))
+
+
+class TestLastReviewsHandler(ApiTestCase):
+
+    @gen_test
+    def test_can_get_last_reviews(self):
+        page = PageFactory.create()
+
+        date_now = datetime(2013, 11, 12, 13, 25, 27)
+
+        review = ReviewFactory.create(
+            page=page,
+            is_active=True,
+            is_complete=False,
+            completed_date=date_now,
+            created_date=date_now)
+
+        review.add_fact('fact', 'value', 'title', 'kb')
+        review.add_violation('violation', 'title', 'description', 100)
+        review.is_complete = True
+        self.db.flush()
+
+        url = self.get_url('/last-reviews')
+        response = yield self.http_client.fetch(url, method='GET')
+
+        expect(response.code).to_equal(200)
+
+        dt = calendar.timegm(date_now.utctimetuple())
+
+        expected = [{
+            'domain': review.domain.name,
+            'page': page.to_dict(),
+            'uuid': str(review.uuid),
+            'isComplete': True,
+            'facts': [
+                {u'key': u'fact', u'value': u'value', u'title': u'title',
+                 u'unit': u'kb'}
+            ],
+            'violations': [
+                {u'points': 100, u'description': u'description',
+                 u'key': u'violation', u'title': u'title'}
+            ],
+            'createdAt': dt,
+            'completedAt': dt,
+            'violationCount': 1,
+            'completedDateISO': date_now.isoformat()
+        }]
+
+        expect(loads(response.body)).to_be_like(expected)
