@@ -3,18 +3,15 @@
 
 from mock import Mock
 from preggy import expect
-from tornado.testing import gen_test
 
-from holmes.utils import get_domain_from_url
 from holmes.config import Config
 from holmes.reviewer import Reviewer
 from holmes.validators.base import Validator
-from tests.fixtures import DomainFactory, PageFactory, ReviewFactory
+from tests.fixtures import PageFactory, ReviewFactory
 from tests.unit.base import ApiTestCase
 
 
 class TestBaseValidator(ApiTestCase):
-    @gen_test
     def test_can_validate(self):
         expect(Validator(None).validate()).to_be_true()
 
@@ -28,28 +25,23 @@ class TestBaseValidator(ApiTestCase):
         Validator(mock_reviewer).get_raw_response('some url')
         mock_reviewer.raw_responses.get.assert_called_once_with('some url', None)
 
-    @gen_test
     def test_can_add_fact(self):
         mock_reviewer = Mock()
         Validator(mock_reviewer).add_fact('test', 10, 'title', 'unit')
         mock_reviewer.add_fact.assert_called_once_with('test', 10, 'title', 'unit')
 
-    @gen_test
     def test_can_add_violation(self):
         mock_reviewer = Mock()
         Validator(mock_reviewer).add_violation('test', 'title', 'description', 100)
         mock_reviewer.add_violation.assert_called_once_with('test', 'title', 'description', 100)
 
-    @gen_test
     def test_can_return_reviewer_info(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        review = ReviewFactory.create()
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
-            page_uuid=page.uuid,
-            page_url=page.url,
+            page_uuid=review.page.uuid,
+            page_url=review.page.url,
             review_uuid=review.uuid,
             config=Config(),
             validators=[]
@@ -57,8 +49,8 @@ class TestBaseValidator(ApiTestCase):
 
         validator = Validator(reviewer)
 
-        expect(validator.page_uuid).to_equal(page.uuid)
-        expect(validator.page_url).to_equal(page.url)
+        expect(validator.page_uuid).to_equal(review.page.uuid)
+        expect(validator.page_url).to_equal(review.page.url)
         expect(validator.review_uuid).to_equal(review.uuid)
         expect(validator.config).to_equal(reviewer.config)
 
@@ -70,11 +62,9 @@ class TestBaseValidator(ApiTestCase):
         validator = Validator(None)
         expect(validator.is_absolute('/index.html')).to_be_false()
 
-    @gen_test
     def test_can_rebase(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create(url='http://globoi.com/test/index.html')
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -85,16 +75,14 @@ class TestBaseValidator(ApiTestCase):
             validators=[]
         )
 
-        _, domain_url = get_domain_from_url(page.url)
         validator = Validator(reviewer)
 
-        expect(validator.rebase('index.html')).to_equal('%s%s' % (domain_url, 'index.html'))
+        expect(validator.rebase('index.png')).to_equal('http://globoi.com/test/index.png')
+        expect(validator.rebase('/index.png')).to_equal('http://globoi.com/index.png')
 
-    @gen_test
     def test_will_call_reviewer_enqueue(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -111,11 +99,9 @@ class TestBaseValidator(ApiTestCase):
 
         reviewer.enqueue.assert_called_once_with('/')
 
-    @gen_test
     def test_will_call_reviewer_add_fact(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -131,11 +117,9 @@ class TestBaseValidator(ApiTestCase):
         validator.add_fact('random.fact', 'random', 'value', 'title')
         reviewer.add_fact.assert_called_once_with('random.fact', 'random', 'value', 'title')
 
-    @gen_test
     def test_will_call_reviewer_add_violation(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -151,11 +135,9 @@ class TestBaseValidator(ApiTestCase):
         validator.add_violation('random.violation', 'random', 'violation', 0)
         reviewer.add_violation.assert_called_once_with('random.violation', 'random', 'violation', 0)
 
-    @gen_test
     def test_will_call_reviewer_get_status_code(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -177,4 +159,3 @@ class TestBaseValidator(ApiTestCase):
         gziped_content = validator.to_gzip(content)
 
         expect(content).to_equal(gziped_content.decode('zip'))
-
