@@ -4,26 +4,23 @@
 from mock import Mock, call
 from preggy import expect
 import lxml.html
-from tornado.testing import gen_test
 
 from holmes.config import Config
 from holmes.reviewer import Reviewer
 from holmes.validators.css_requests import CSSRequestsValidator
 from tests.unit.base import ValidatorTestCase
-from tests.fixtures import DomainFactory, PageFactory, ReviewFactory
+from tests.fixtures import PageFactory, ReviewFactory
 
 
 class TestCSSRequestsValidator(ValidatorTestCase):
 
-    @gen_test
     def test_can_validate_css_requests_on_globo_html(self):
         config = Config()
         config.MAX_CSS_REQUESTS_PER_PAGE = 1
         config.MAX_CSS_KB_PER_PAGE_AFTER_GZIP = 0.0
 
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -101,13 +98,11 @@ class TestCSSRequestsValidator(ValidatorTestCase):
                 points=0
             ))
 
-    @gen_test
     def test_can_validate_css_requests_zero_requests(self):
         config = Config()
 
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -162,13 +157,11 @@ class TestCSSRequestsValidator(ValidatorTestCase):
 
         expect(validator.add_violation.called).to_be_false()
 
-    @gen_test
     def test_can_validate_css_requests_empty_html(self):
         config = Config()
 
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
