@@ -3,23 +3,20 @@
 
 from mock import Mock
 from preggy import expect
-from tornado.testing import gen_test
 import lxml.html
 
 from holmes.config import Config
 from holmes.reviewer import Reviewer
 from holmes.validators.title import TitleValidator
 from tests.unit.base import ValidatorTestCase
-from tests.fixtures import DomainFactory, PageFactory, ReviewFactory
+from tests.fixtures import PageFactory, ReviewFactory
 
 
 class TestTitleValidator(ValidatorTestCase):
 
-    @gen_test
     def test_can_validate_title(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -51,15 +48,13 @@ class TestTitleValidator(ValidatorTestCase):
         validator.add_fact.assert_called_once_with(
             key='page.title',
             value=u'globo.com - Absolutamente tudo sobre not\xedcias, esportes e entretenimento',
-            title='Title')
+            title='Page Title')
 
         expect(validator.add_violation.called).to_be_false()
 
-    @gen_test
     def test_can_validate_title_with_size_violation(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -91,7 +86,7 @@ class TestTitleValidator(ValidatorTestCase):
         validator.add_fact.assert_called_once_with(
             key='page.title',
             value='%s' % ('*' * reviewer.config.MAX_TITLE_SIZE) + '*',
-            title='Title')
+            title='Page Title')
 
         validator.add_violation.assert_called_once_with(
             key='page.title.exceed',
@@ -99,11 +94,9 @@ class TestTitleValidator(ValidatorTestCase):
             description="Title tags to long may be truncated in the results",
             points=50)
 
-    @gen_test
     def test_can_validate_empty_title(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -140,11 +133,9 @@ class TestTitleValidator(ValidatorTestCase):
             description="Title was not found on %s" % page.url,
             points=50)
 
-    @gen_test
     def test_can_validate_no_title_tag(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -181,11 +172,9 @@ class TestTitleValidator(ValidatorTestCase):
             description="Title was not found on %s" % page.url,
             points=50)
 
-    @gen_test
     def test_can_validate_empty_html(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
@@ -222,11 +211,9 @@ class TestTitleValidator(ValidatorTestCase):
             description="Title was not found on %s" % page.url,
             points=50)
 
-    @gen_test
     def test_can_validate_multiple_title(self):
-        domain = yield DomainFactory.create()
-        page = yield PageFactory.create(domain=domain)
-        review = yield ReviewFactory.create(page=page)
+        page = PageFactory.create()
+        review = ReviewFactory.create(page=page)
 
         reviewer = Reviewer(
             api_url='http://localhost:2368',
